////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  hnr_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "hnr_1_0_0.h"
#include "parametersetmanager.h"

HNR_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_gain_arr_tab") == 0)
    {
        __result = lnr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lnr_shift") == 0)
    {
        ParameterUtils::DoubleToString((double)lnr_shift, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "radial_noise_prsv_adj_tab") == 0)
    {
        __result = radial_noise_prsv_adj_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "cnr_gain_arr_tab") == 0)
    {
        __result = cnr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_u") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_low_thrd_u, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_v") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_low_thrd_v, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_u") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_low_gap_u, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_v") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_low_gap_v, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_adj_gain") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_adj_gain, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_scale") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_scale, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_arr_tab") == 0)
    {
        __result = fnr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_clamp_arr_tab") == 0)
    {
        __result = fnr_gain_clamp_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_th_tab") == 0)
    {
        __result = fnr_ac_th_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_shift") == 0)
    {
        ParameterUtils::DoubleToString((double)fnr_ac_shift, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "filtering_nr_gain_arr_tab") == 0)
    {
        __result = filtering_nr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "abs_amp_shift") == 0)
    {
        ParameterUtils::DoubleToString((double)abs_amp_shift, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_percent") == 0)
    {
        ParameterUtils::DoubleToString((double)lpf3_percent, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_offset") == 0)
    {
        ParameterUtils::DoubleToString((double)lpf3_offset, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_strength") == 0)
    {
        ParameterUtils::DoubleToString((double)lpf3_strength, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "blend_lnr_gain_arr_tab") == 0)
    {
        __result = blend_lnr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_adj_gain") == 0)
    {
        ParameterUtils::DoubleToString((double)blend_cnr_adj_gain, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_gain_arr_tab") == 0)
    {
        __result = blend_snr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_min") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_hue_min, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_max") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_hue_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_min") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_y_min, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_max") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_y_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_max") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_saturation_min_y_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_max") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_saturation_max_y_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_min") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_saturation_min_y_min, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_min") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_saturation_max_y_min, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_boundary_probability") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_boundary_probability, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_percent") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_percent, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "skin_non_skin_to_skin_q_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)skin_non_skin_to_skin_q_ratio, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "face_boundary") == 0)
    {
        ParameterUtils::DoubleToString((double)face_boundary, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "face_transition") == 0)
    {
        ParameterUtils::DoubleToString((double)face_transition, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "snr_gain_arr_tab") == 0)
    {
        __result = snr_gain_arr_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "snr_skin_smoothing_str") == 0)
    {
        ParameterUtils::DoubleToString((double)snr_skin_smoothing_str, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool hnr10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_gain_arr_tab") == 0)
    {
        __result = lnr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lnr_shift") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lnr_shift = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "radial_noise_prsv_adj_tab") == 0)
    {
        __result = radial_noise_prsv_adj_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "cnr_gain_arr_tab") == 0)
    {
        __result = cnr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_u") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_low_thrd_u = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_v") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_low_thrd_v = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_u") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_low_gap_u = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_v") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_low_gap_v = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_adj_gain") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_adj_gain = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_scale") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_scale = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_arr_tab") == 0)
    {
        __result = fnr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_clamp_arr_tab") == 0)
    {
        __result = fnr_gain_clamp_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_th_tab") == 0)
    {
        __result = fnr_ac_th_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_shift") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            fnr_ac_shift = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "filtering_nr_gain_arr_tab") == 0)
    {
        __result = filtering_nr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "abs_amp_shift") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            abs_amp_shift = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_percent") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lpf3_percent = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_offset") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lpf3_offset = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_strength") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lpf3_strength = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "blend_lnr_gain_arr_tab") == 0)
    {
        __result = blend_lnr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_adj_gain") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            blend_cnr_adj_gain = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_gain_arr_tab") == 0)
    {
        __result = blend_snr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_min") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_hue_min = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_hue_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_min") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_y_min = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_y_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_saturation_min_y_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_saturation_max_y_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_min") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_saturation_min_y_min = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_min") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_saturation_max_y_min = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_boundary_probability") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_boundary_probability = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_percent") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_percent = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "skin_non_skin_to_skin_q_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            skin_non_skin_to_skin_q_ratio = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "face_boundary") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            face_boundary = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "face_transition") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            face_transition = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "snr_gain_arr_tab") == 0)
    {
        __result = snr_gain_arr_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "snr_skin_smoothing_str") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            snr_skin_smoothing_str = (float)dblValue; 
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lnr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lnr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lnr_gain_arr_tab") == 0)
    {
        __result = lnr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // lnr_shift
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lnr_shift", ParameterParserDataType::UInt32, (double)lnr_shift, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lnr_shift") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)lnr_shift, 0));
    }

    // radial_noise_prsv_adj_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_noise_prsv_adj_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "radial_noise_prsv_adj_tab") == 0)
    {
        __result = radial_noise_prsv_adj_tab.GetInfo(&__path[__pos], __info);
    }

    // cnr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_gain_arr_tab") == 0)
    {
        __result = cnr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // cnr_low_thrd_u
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_low_thrd_u", ParameterParserDataType::Int32, (double)cnr_low_thrd_u, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_u") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)cnr_low_thrd_u, 0));
    }

    // cnr_low_thrd_v
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_low_thrd_v", ParameterParserDataType::Int32, (double)cnr_low_thrd_v, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_thrd_v") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)cnr_low_thrd_v, 0));
    }

    // cnr_low_gap_u
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_low_gap_u", ParameterParserDataType::UInt32, (double)cnr_low_gap_u, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_u") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)cnr_low_gap_u, 0));
    }

    // cnr_low_gap_v
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_low_gap_v", ParameterParserDataType::UInt32, (double)cnr_low_gap_v, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_low_gap_v") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)cnr_low_gap_v, 0));
    }

    // cnr_adj_gain
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_adj_gain", ParameterParserDataType::UInt32, (double)cnr_adj_gain, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_adj_gain") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)cnr_adj_gain, 0));
    }

    // cnr_scale
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_scale", ParameterParserDataType::UInt32, (double)cnr_scale, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_scale") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)cnr_scale, 0));
    }

    // fnr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_arr_tab") == 0)
    {
        __result = fnr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // fnr_gain_clamp_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_gain_clamp_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "fnr_gain_clamp_arr_tab") == 0)
    {
        __result = fnr_gain_clamp_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // fnr_ac_th_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_ac_th_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_th_tab") == 0)
    {
        __result = fnr_ac_th_tab.GetInfo(&__path[__pos], __info);
    }

    // fnr_ac_shift
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_ac_shift", ParameterParserDataType::UInt32, (double)fnr_ac_shift, 0));
    }
    else if (PARAMETER_STRCMP(__name, "fnr_ac_shift") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)fnr_ac_shift, 0));
    }

    // filtering_nr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("filtering_nr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "filtering_nr_gain_arr_tab") == 0)
    {
        __result = filtering_nr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // abs_amp_shift
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("abs_amp_shift", ParameterParserDataType::UInt32, (double)abs_amp_shift, 0));
    }
    else if (PARAMETER_STRCMP(__name, "abs_amp_shift") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)abs_amp_shift, 0));
    }

    // lpf3_percent
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lpf3_percent", ParameterParserDataType::UInt32, (double)lpf3_percent, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_percent") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)lpf3_percent, 0));
    }

    // lpf3_offset
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lpf3_offset", ParameterParserDataType::UInt32, (double)lpf3_offset, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_offset") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)lpf3_offset, 0));
    }

    // lpf3_strength
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lpf3_strength", ParameterParserDataType::UInt32, (double)lpf3_strength, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_strength") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)lpf3_strength, 0));
    }

    // blend_lnr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_lnr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "blend_lnr_gain_arr_tab") == 0)
    {
        __result = blend_lnr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // blend_cnr_adj_gain
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_cnr_adj_gain", ParameterParserDataType::UInt32, (double)blend_cnr_adj_gain, 0));
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_adj_gain") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)blend_cnr_adj_gain, 0));
    }

    // blend_snr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_snr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_gain_arr_tab") == 0)
    {
        __result = blend_snr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // skin_hue_min
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_hue_min", ParameterParserDataType::Float, (double)skin_hue_min));
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_min") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_hue_min));
    }

    // skin_hue_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_hue_max", ParameterParserDataType::Float, (double)skin_hue_max));
    }
    else if (PARAMETER_STRCMP(__name, "skin_hue_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_hue_max));
    }

    // skin_y_min
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_y_min", ParameterParserDataType::Float, (double)skin_y_min));
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_min") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_y_min));
    }

    // skin_y_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_y_max", ParameterParserDataType::Float, (double)skin_y_max));
    }
    else if (PARAMETER_STRCMP(__name, "skin_y_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_y_max));
    }

    // skin_saturation_min_y_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_saturation_min_y_max", ParameterParserDataType::Float, (double)skin_saturation_min_y_max));
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_saturation_min_y_max));
    }

    // skin_saturation_max_y_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_saturation_max_y_max", ParameterParserDataType::Float, (double)skin_saturation_max_y_max));
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_saturation_max_y_max));
    }

    // skin_saturation_min_y_min
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_saturation_min_y_min", ParameterParserDataType::Float, (double)skin_saturation_min_y_min));
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_min_y_min") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_saturation_min_y_min));
    }

    // skin_saturation_max_y_min
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_saturation_max_y_min", ParameterParserDataType::Float, (double)skin_saturation_max_y_min));
    }
    else if (PARAMETER_STRCMP(__name, "skin_saturation_max_y_min") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_saturation_max_y_min));
    }

    // skin_boundary_probability
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_boundary_probability", ParameterParserDataType::UInt32, (double)skin_boundary_probability, 0));
    }
    else if (PARAMETER_STRCMP(__name, "skin_boundary_probability") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)skin_boundary_probability, 0));
    }

    // skin_percent
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_percent", ParameterParserDataType::Float, (double)skin_percent));
    }
    else if (PARAMETER_STRCMP(__name, "skin_percent") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_percent));
    }

    // skin_non_skin_to_skin_q_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("skin_non_skin_to_skin_q_ratio", ParameterParserDataType::Float, (double)skin_non_skin_to_skin_q_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "skin_non_skin_to_skin_q_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)skin_non_skin_to_skin_q_ratio));
    }

    // face_boundary
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("face_boundary", ParameterParserDataType::Float, (double)face_boundary));
    }
    else if (PARAMETER_STRCMP(__name, "face_boundary") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)face_boundary));
    }

    // face_transition
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("face_transition", ParameterParserDataType::Float, (double)face_transition));
    }
    else if (PARAMETER_STRCMP(__name, "face_transition") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)face_transition));
    }

    // snr_gain_arr_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("snr_gain_arr_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "snr_gain_arr_tab") == 0)
    {
        __result = snr_gain_arr_tab.GetInfo(&__path[__pos], __info);
    }

    // snr_skin_smoothing_str
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("snr_skin_smoothing_str", ParameterParserDataType::UInt32, (double)snr_skin_smoothing_str, 0));
    }
    else if (PARAMETER_STRCMP(__name, "snr_skin_smoothing_str") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)snr_skin_smoothing_str, 0));
    }

    return __result;
}

bool hnr10_rgn_dataType::lnr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_gain_arr") == 0)
    {
        if (__index < 33)
        {
            ParameterUtils::DoubleToString((double)lnr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 33; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)lnr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::lnr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_gain_arr") == 0)
    {
        if (__index < 33)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                lnr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 33)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    lnr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::lnr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lnr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lnr_gain_arr", ParameterParserDataType::UInt32, true, false, 33));
    }

    return __result;
}

bool hnr10_rgn_dataType::radial_noise_prsv_adj_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_noise_prsv_adj") == 0)
    {
        if (__index < 7)
        {
            ParameterUtils::DoubleToString((double)radial_noise_prsv_adj[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 7; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)radial_noise_prsv_adj[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::radial_noise_prsv_adj_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_noise_prsv_adj") == 0)
    {
        if (__index < 7)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                radial_noise_prsv_adj[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 7)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    radial_noise_prsv_adj[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::radial_noise_prsv_adj_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_noise_prsv_adj
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_noise_prsv_adj", ParameterParserDataType::Float, true, false, 7));
    }

    return __result;
}

bool hnr10_rgn_dataType::cnr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cnr_gain_arr") == 0)
    {
        if (__index < 25)
        {
            ParameterUtils::DoubleToString((double)cnr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 25; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)cnr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::cnr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cnr_gain_arr") == 0)
    {
        if (__index < 25)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                cnr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 25)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    cnr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::cnr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // cnr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_gain_arr", ParameterParserDataType::UInt32, true, false, 25));
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)fnr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)fnr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                fnr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    fnr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // fnr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_gain_arr", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_clamp_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_gain_clamp_arr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)fnr_gain_clamp_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)fnr_gain_clamp_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_clamp_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_gain_clamp_arr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                fnr_gain_clamp_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    fnr_gain_clamp_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_gain_clamp_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // fnr_gain_clamp_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_gain_clamp_arr", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_ac_th_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_ac_th") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)fnr_ac_th[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)fnr_ac_th[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_ac_th_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "fnr_ac_th") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                fnr_ac_th[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    fnr_ac_th[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::fnr_ac_th_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // fnr_ac_th
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_ac_th", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool hnr10_rgn_dataType::filtering_nr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "filtering_nr_gain_arr") == 0)
    {
        if (__index < 33)
        {
            ParameterUtils::DoubleToString((double)filtering_nr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 33; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)filtering_nr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::filtering_nr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "filtering_nr_gain_arr") == 0)
    {
        if (__index < 33)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                filtering_nr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 33)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    filtering_nr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::filtering_nr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // filtering_nr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("filtering_nr_gain_arr", ParameterParserDataType::UInt32, true, false, 33));
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_lnr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "blend_lnr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)blend_lnr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)blend_lnr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_lnr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "blend_lnr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                blend_lnr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    blend_lnr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_lnr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // blend_lnr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_lnr_gain_arr", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_snr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "blend_snr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)blend_snr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)blend_snr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_snr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "blend_snr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                blend_snr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    blend_snr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::blend_snr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // blend_snr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_snr_gain_arr", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool hnr10_rgn_dataType::snr_gain_arr_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "snr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)snr_gain_arr[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)snr_gain_arr[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::snr_gain_arr_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "snr_gain_arr") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                snr_gain_arr[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    snr_gain_arr[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool hnr10_rgn_dataType::snr_gain_arr_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // snr_gain_arr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("snr_gain_arr", ParameterParserDataType::UInt32, true, false, 17));
    }

    return __result;
}

bool mod_hnr10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hnr10_rgn_data") == 0)
    {
        __result = hnr10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_hnr10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hnr10_rgn_data") == 0)
    {
        __result = hnr10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_hnr10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hnr10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hnr10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hnr10_rgn_data") == 0)
    {
        __result = hnr10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_aec_data") == 0)
    {
        if (__index < mod_hnr10_aec_dataCount)
        {
            __result = mod_hnr10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_aec_data") == 0)
    {
        if (__index < mod_hnr10_aec_dataCount)
        {
            __result = mod_hnr10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_hnr10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_hnr10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_hnr10_aec_data", ParameterParserDataType::Structure, true, false, mod_hnr10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_hnr10_aec_data") == 0)
    {
        if (__index < mod_hnr10_aec_dataCount)
        {
            __result = mod_hnr10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_hnr10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_hdr_aec_data") == 0)
    {
        if (__index < mod_hnr10_hdr_aec_dataCount)
        {
            __result = mod_hnr10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_hdr_aec_data") == 0)
    {
        if (__index < mod_hnr10_hdr_aec_dataCount)
        {
            __result = mod_hnr10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_hnr10_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_hnr10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_hnr10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_hnr10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_hnr10_hdr_aec_data") == 0)
    {
        if (__index < mod_hnr10_hdr_aec_dataCount)
        {
            __result = mod_hnr10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_hnr10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // total_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("total_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // total_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("total_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::total_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_drc_gain_data") == 0)
    {
        if (__index < mod_hnr10_drc_gain_dataCount)
        {
            __result = mod_hnr10_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::total_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_drc_gain_data") == 0)
    {
        if (__index < mod_hnr10_drc_gain_dataCount)
        {
            __result = mod_hnr10_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_hnr10_total_scale_ratio_dataType::total_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_hnr10_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_hnr10_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_hnr10_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_hnr10_drc_gain_data") == 0)
    {
        if (__index < mod_hnr10_drc_gain_dataCount)
        {
            __result = mod_hnr10_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_hnr10_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_hnr10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_total_scale_ratio_data") == 0)
    {
        if (__index < mod_hnr10_total_scale_ratio_dataCount)
        {
            __result = mod_hnr10_total_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_hnr10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_hnr10_total_scale_ratio_data") == 0)
    {
        if (__index < mod_hnr10_total_scale_ratio_dataCount)
        {
            __result = mod_hnr10_total_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_hnr10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_hnr10_total_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_hnr10_total_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_hnr10_total_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_hnr10_total_scale_ratio_data") == 0)
    {
        if (__index < mod_hnr10_total_scale_ratio_dataCount)
        {
            __result = mod_hnr10_total_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_hnr10_total_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool chromatix_hnr10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)lnr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "rnr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)rnr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "cnr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)cnr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "snr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)snr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "fd_snr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)fd_snr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "fnr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)fnr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_en") == 0)
    {
        ParameterUtils::DoubleToString((double)lpf3_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)blend_cnr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_en") == 0)
    {
        ParameterUtils::DoubleToString((double)blend_snr_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_hnr10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lnr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lnr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "rnr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            rnr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "cnr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            cnr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "snr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            snr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "fd_snr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            fd_snr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "fnr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            fnr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lpf3_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            blend_cnr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            blend_snr_en = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_hnr10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lnr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lnr_en", ParameterParserDataType::Int32, (double)lnr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lnr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)lnr_en, 0));
    }

    // rnr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("rnr_en", ParameterParserDataType::Int32, (double)rnr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "rnr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)rnr_en, 0));
    }

    // cnr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cnr_en", ParameterParserDataType::Int32, (double)cnr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "cnr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)cnr_en, 0));
    }

    // snr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("snr_en", ParameterParserDataType::Int32, (double)snr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "snr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)snr_en, 0));
    }

    // fd_snr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fd_snr_en", ParameterParserDataType::Int32, (double)fd_snr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "fd_snr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)fd_snr_en, 0));
    }

    // fnr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fnr_en", ParameterParserDataType::Int32, (double)fnr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "fnr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)fnr_en, 0));
    }

    // lpf3_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lpf3_en", ParameterParserDataType::Int32, (double)lpf3_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lpf3_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)lpf3_en, 0));
    }

    // blend_cnr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_cnr_en", ParameterParserDataType::Int32, (double)blend_cnr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "blend_cnr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)blend_cnr_en, 0));
    }

    // blend_snr_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("blend_snr_en", ParameterParserDataType::Int32, (double)blend_snr_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "blend_snr_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)blend_snr_en, 0));
    }

    // radial_anchor_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_anchor_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_hnr10_reserveType::radial_anchor_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor") == 0)
    {
        if (__index < 7)
        {
            ParameterUtils::DoubleToString((double)radial_anchor[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 7; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)radial_anchor[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_hnr10_reserveType::radial_anchor_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor") == 0)
    {
        if (__index < 7)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                radial_anchor[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 7)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    radial_anchor[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_hnr10_reserveType::radial_anchor_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_anchor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_anchor", ParameterParserDataType::Float, true, false, 7));
    }

    return __result;
}

bool chromatix_hnr10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_reserve") == 0)
    {
        __result = chromatix_hnr10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_core") == 0)
    {
        __result = chromatix_hnr10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_hnr10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_reserve") == 0)
    {
        __result = chromatix_hnr10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_core") == 0)
    {
        __result = chromatix_hnr10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_hnr10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // dynamic_enable_triggers
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dynamic_enable_triggers", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetInfo(&__path[__pos], __info);
    }

    // chromatix_hnr10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_hnr10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_reserve") == 0)
    {
        __result = chromatix_hnr10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_hnr10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_hnr10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_hnr10_core") == 0)
    {
        __result = chromatix_hnr10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_hnr10Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)hnr_nr_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hnr_blend_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)hnr_blend_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_hnr10Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hnr_nr_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hnr_blend_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hnr_blend_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_hnr10Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hnr_nr_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hnr_nr_enable", ParameterParserDataType::Int32, (double)hnr_nr_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)hnr_nr_enable, 0));
    }

    // hnr_blend_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hnr_blend_enable", ParameterParserDataType::Int32, (double)hnr_blend_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hnr_blend_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)hnr_blend_enable, 0));
    }

    return __result;
}

bool chromatix_hnr10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_hnr10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_hnr10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_hnr10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_hnr10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_hnr10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_hnr10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 4)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 4; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_hnr10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 4)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 4)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_hnr10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 4));
    }

    return __result;
}

bool chromatix_hnr10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_hnr10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_hnr10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        __result = hnr_nr_enable.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        __result = hnr_nr_enable.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hnr_nr_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hnr_nr_enable", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hnr_nr_enable") == 0)
    {
        __result = hnr_nr_enable.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::hnr_nr_enableStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_control_var, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_mode, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::hnr_nr_enableStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_control_var = (ispglobalelements::control_var_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_mode = (ispglobalelements::hyst_direction)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_hnr10Type::dynamic_enable_triggersStruct::hnr_nr_enableStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Int32, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enable, 0));
    }

    // hyst_control_var
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_control_var", ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }

    // hyst_mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_mode", ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }

    // hyst_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_total_scale_ratio):
            enumValue = chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum::control_total_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_hnr10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_hnr10TypeClass::chromatix_hnr10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_hnr10_reserve);
    PARAMETER_INITIALIZE(chromatix_hnr10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_hnr10TypeClass::chromatix_hnr10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_hnr10_reserve);
    PARAMETER_INITIALIZE(chromatix_hnr10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_hnr10TypeClass::~chromatix_hnr10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_hnr10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "hnr10_bps")) == 0)
    {
        name = "hnr10_bps";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "hnr10_ipe")) == 0)
    {
        name = "hnr10_ipe";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lnr_gain_arr_tab);
    PARAMETER_INITIALIZE(lnr_shift);
    PARAMETER_INITIALIZE(radial_noise_prsv_adj_tab);
    PARAMETER_INITIALIZE(cnr_gain_arr_tab);
    PARAMETER_INITIALIZE(cnr_low_thrd_u);
    PARAMETER_INITIALIZE(cnr_low_thrd_v);
    PARAMETER_INITIALIZE(cnr_low_gap_u);
    PARAMETER_INITIALIZE(cnr_low_gap_v);
    PARAMETER_INITIALIZE(cnr_adj_gain);
    PARAMETER_INITIALIZE(cnr_scale);
    PARAMETER_INITIALIZE(fnr_gain_arr_tab);
    PARAMETER_INITIALIZE(fnr_gain_clamp_arr_tab);
    PARAMETER_INITIALIZE(fnr_ac_th_tab);
    PARAMETER_INITIALIZE(fnr_ac_shift);
    PARAMETER_INITIALIZE(filtering_nr_gain_arr_tab);
    PARAMETER_INITIALIZE(abs_amp_shift);
    PARAMETER_INITIALIZE(lpf3_percent);
    PARAMETER_INITIALIZE(lpf3_offset);
    PARAMETER_INITIALIZE(lpf3_strength);
    PARAMETER_INITIALIZE(blend_lnr_gain_arr_tab);
    PARAMETER_INITIALIZE(blend_cnr_adj_gain);
    PARAMETER_INITIALIZE(blend_snr_gain_arr_tab);
    PARAMETER_INITIALIZE(skin_hue_min);
    PARAMETER_INITIALIZE(skin_hue_max);
    PARAMETER_INITIALIZE(skin_y_min);
    PARAMETER_INITIALIZE(skin_y_max);
    PARAMETER_INITIALIZE(skin_saturation_min_y_max);
    PARAMETER_INITIALIZE(skin_saturation_max_y_max);
    PARAMETER_INITIALIZE(skin_saturation_min_y_min);
    PARAMETER_INITIALIZE(skin_saturation_max_y_min);
    PARAMETER_INITIALIZE(skin_boundary_probability);
    PARAMETER_INITIALIZE(skin_percent);
    PARAMETER_INITIALIZE(skin_non_skin_to_skin_q_ratio);
    PARAMETER_INITIALIZE(face_boundary);
    PARAMETER_INITIALIZE(face_transition);
    PARAMETER_INITIALIZE(snr_gain_arr_tab);
    PARAMETER_INITIALIZE(snr_skin_smoothing_str);

    result = lnr_gain_arr_tab.Load(entry, alignment);
    SYMBOL_TABLE_ENTRY_READ(entry, result, lnr_shift, alignment)
    if (result)
    {
        result = radial_noise_prsv_adj_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = cnr_gain_arr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_low_thrd_u, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_low_thrd_v, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_low_gap_u, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_low_gap_v, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_adj_gain, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_scale, alignment)
    if (result)
    {
        result = fnr_gain_arr_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = fnr_gain_clamp_arr_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = fnr_ac_th_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, fnr_ac_shift, alignment)
    if (result)
    {
        result = filtering_nr_gain_arr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, abs_amp_shift, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lpf3_percent, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lpf3_offset, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lpf3_strength, alignment)
    if (result)
    {
        result = blend_lnr_gain_arr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, blend_cnr_adj_gain, alignment)
    if (result)
    {
        result = blend_snr_gain_arr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_hue_min, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_hue_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_y_min, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_y_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_saturation_min_y_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_saturation_max_y_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_saturation_min_y_min, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_saturation_max_y_min, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_boundary_probability, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_percent, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, skin_non_skin_to_skin_q_ratio, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, face_boundary, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, face_transition, alignment)
    if (result)
    {
        result = snr_gain_arr_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, snr_skin_smoothing_str, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_lnr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::lnr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lnr_gain_arr);

    result = entry->ReadArray(lnr_gain_arr, 33, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_radial_noise_prsv_adj_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::radial_noise_prsv_adj_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_noise_prsv_adj);

    result = entry->ReadArray(radial_noise_prsv_adj, 7, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_cnr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::cnr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(cnr_gain_arr);

    result = entry->ReadArray(cnr_gain_arr, 25, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_fnr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::fnr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(fnr_gain_arr);

    result = entry->ReadArray(fnr_gain_arr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_fnr_gain_clamp_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::fnr_gain_clamp_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(fnr_gain_clamp_arr);

    result = entry->ReadArray(fnr_gain_clamp_arr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_fnr_ac_th_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::fnr_ac_th_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(fnr_ac_th);

    result = entry->ReadArray(fnr_ac_th, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_filtering_nr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::filtering_nr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(filtering_nr_gain_arr);

    result = entry->ReadArray(filtering_nr_gain_arr, 33, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_blend_lnr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::blend_lnr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(blend_lnr_gain_arr);

    result = entry->ReadArray(blend_lnr_gain_arr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_blend_snr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::blend_snr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(blend_snr_gain_arr);

    result = entry->ReadArray(blend_snr_gain_arr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load hnr10_rgn_dataType_snr_gain_arr_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool hnr10_rgn_dataType::snr_gain_arr_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(snr_gain_arr);

    result = entry->ReadArray(snr_gain_arr, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(hnr10_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hnr10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_hnr10_aec_data);


    // Reading Array mod_hnr10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_hnr10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_hnr10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_hnr10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_hnr10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_hnr10_aec_dataCount, file, line);
            if (mod_hnr10_aec_dataDupInfo != nullptr && mod_hnr10_aec_dataDupInfo->Object != nullptr)
            {
                mod_hnr10_aec_data = (mod_hnr10_aec_dataType*)mod_hnr10_aec_dataDupInfo->Object;
                if (mod_hnr10_aec_data == nullptr)
                {
                    if (mod_hnr10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_hnr10_aec_dataDupInfo->File, mod_hnr10_aec_dataDupInfo->Line, mod_hnr10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_hnr10_aec_dataDupInfo->Line, mod_hnr10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_hnr10_aec_data == nullptr)
            {
                if (result && mod_hnr10_aec_dataCount > 0)
                {
                    mod_hnr10_aec_data = PARAMETER_NEW mod_hnr10_aec_dataType[mod_hnr10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_hnr10_aec_data, mod_hnr10_aec_dataCount, file, line);
                }
                if (!result || mod_hnr10_aec_data == nullptr)
                {
                    if (mod_hnr10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_hnr10_aec_data\n");
                    }
                    mod_hnr10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_hnr10_aec_dataCount; i++)
                {
                    result = mod_hnr10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_hnr10_aec_data == nullptr)
        {
            mod_hnr10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_hnr10_hdr_aec_data);


    // Reading Array mod_hnr10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_hnr10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_hnr10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_hnr10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_hnr10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_hnr10_hdr_aec_dataCount, file, line);
            if (mod_hnr10_hdr_aec_dataDupInfo != nullptr && mod_hnr10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_hnr10_hdr_aec_data = (mod_hnr10_hdr_aec_dataType*)mod_hnr10_hdr_aec_dataDupInfo->Object;
                if (mod_hnr10_hdr_aec_data == nullptr)
                {
                    if (mod_hnr10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_hnr10_hdr_aec_dataDupInfo->File, mod_hnr10_hdr_aec_dataDupInfo->Line, mod_hnr10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_hnr10_hdr_aec_dataDupInfo->Line, mod_hnr10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_hnr10_hdr_aec_data == nullptr)
            {
                if (result && mod_hnr10_hdr_aec_dataCount > 0)
                {
                    mod_hnr10_hdr_aec_data = PARAMETER_NEW mod_hnr10_hdr_aec_dataType[mod_hnr10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_hnr10_hdr_aec_data, mod_hnr10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_hnr10_hdr_aec_data == nullptr)
                {
                    if (mod_hnr10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_hnr10_hdr_aec_data\n");
                    }
                    mod_hnr10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_hnr10_hdr_aec_dataCount; i++)
                {
                    result = mod_hnr10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_hnr10_hdr_aec_data == nullptr)
        {
            mod_hnr10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_total_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_total_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(total_scale_ratio_trigger);
    PARAMETER_INITIALIZE(total_scale_ratio_data);

    result = total_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = total_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_hnr10_total_scale_ratio_dataType_total_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_hnr10_total_scale_ratio_dataType::total_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_hnr10_drc_gain_data);


    // Reading Array mod_hnr10_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_hnr10_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_hnr10_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_hnr10_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_hnr10_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_hnr10_drc_gain_dataCount, file, line);
            if (mod_hnr10_drc_gain_dataDupInfo != nullptr && mod_hnr10_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_hnr10_drc_gain_data = (mod_hnr10_drc_gain_dataType*)mod_hnr10_drc_gain_dataDupInfo->Object;
                if (mod_hnr10_drc_gain_data == nullptr)
                {
                    if (mod_hnr10_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_hnr10_drc_gain_dataDupInfo->File, mod_hnr10_drc_gain_dataDupInfo->Line, mod_hnr10_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_hnr10_drc_gain_dataDupInfo->Line, mod_hnr10_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_hnr10_drc_gain_data == nullptr)
            {
                if (result && mod_hnr10_drc_gain_dataCount > 0)
                {
                    mod_hnr10_drc_gain_data = PARAMETER_NEW mod_hnr10_drc_gain_dataType[mod_hnr10_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_hnr10_drc_gain_data, mod_hnr10_drc_gain_dataCount, file, line);
                }
                if (!result || mod_hnr10_drc_gain_data == nullptr)
                {
                    if (mod_hnr10_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_hnr10_drc_gain_data\n");
                    }
                    mod_hnr10_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_hnr10_drc_gain_dataCount; i++)
                {
                    result = mod_hnr10_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_hnr10_drc_gain_data == nullptr)
        {
            mod_hnr10_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_hnr10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_hnr10_total_scale_ratio_data);


    // Reading Array mod_hnr10_total_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_hnr10_total_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_hnr10_total_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_hnr10_total_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_hnr10_total_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_hnr10_total_scale_ratio_dataCount, file, line);
            if (mod_hnr10_total_scale_ratio_dataDupInfo != nullptr && mod_hnr10_total_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_hnr10_total_scale_ratio_data = (mod_hnr10_total_scale_ratio_dataType*)mod_hnr10_total_scale_ratio_dataDupInfo->Object;
                if (mod_hnr10_total_scale_ratio_data == nullptr)
                {
                    if (mod_hnr10_total_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_total_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_hnr10_total_scale_ratio_dataDupInfo->File, mod_hnr10_total_scale_ratio_dataDupInfo->Line, mod_hnr10_total_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_hnr10_total_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_hnr10_total_scale_ratio_dataDupInfo->Line, mod_hnr10_total_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_hnr10_total_scale_ratio_data == nullptr)
            {
                if (result && mod_hnr10_total_scale_ratio_dataCount > 0)
                {
                    mod_hnr10_total_scale_ratio_data = PARAMETER_NEW mod_hnr10_total_scale_ratio_dataType[mod_hnr10_total_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_hnr10_total_scale_ratio_data, mod_hnr10_total_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_hnr10_total_scale_ratio_data == nullptr)
                {
                    if (mod_hnr10_total_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_hnr10_total_scale_ratio_data\n");
                    }
                    mod_hnr10_total_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_hnr10_total_scale_ratio_dataCount; i++)
                {
                    result = mod_hnr10_total_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_hnr10_total_scale_ratio_data == nullptr)
        {
            mod_hnr10_total_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_hnr10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lnr_en);
    PARAMETER_INITIALIZE(rnr_en);
    PARAMETER_INITIALIZE(cnr_en);
    PARAMETER_INITIALIZE(snr_en);
    PARAMETER_INITIALIZE(fd_snr_en);
    PARAMETER_INITIALIZE(fnr_en);
    PARAMETER_INITIALIZE(lpf3_en);
    PARAMETER_INITIALIZE(blend_cnr_en);
    PARAMETER_INITIALIZE(blend_snr_en);
    PARAMETER_INITIALIZE(radial_anchor_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, lnr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, rnr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, cnr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, snr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, fd_snr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, fnr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lpf3_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, blend_cnr_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, blend_snr_en, alignment)
    if (result)
    {
        result = radial_anchor_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_hnr10_reserveType_radial_anchor_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10_reserveType::radial_anchor_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_anchor);

    result = entry->ReadArray(radial_anchor, 7, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_hnr10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_hnr10_reserve);
    PARAMETER_INITIALIZE(chromatix_hnr10_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = dynamic_enable_triggers.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_hnr10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_hnr10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hnr_nr_enable);
    PARAMETER_INITIALIZE(hnr_blend_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, hnr_nr_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, hnr_blend_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 4; i++)
    {
        result = chromatix_hnr10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::dynamic_enable_triggersStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hnr_nr_enable);

    result = hnr_nr_enable.Load(entry, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct_hnr_nr_enableStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10Type::dynamic_enable_triggersStruct::hnr_nr_enableStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(hyst_control_var);
    PARAMETER_INITIALIZE(hyst_mode);
    PARAMETER_INITIALIZE(hyst_trigger);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    if (result)
    {
        result = ispglobalelements::ReadEnum_control_var_type(entry, hyst_control_var, alignment);
    }
    if (result)
    {
        result = ispglobalelements::ReadEnum_hyst_direction(entry, hyst_mode, alignment);
    }
    if (result)
    {
        result = hyst_trigger.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_hnr10_aec_data))
    {
        PARAMETER_DELETE[] mod_hnr10_aec_data;
    }
    mod_hnr10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_hnr10_hdr_aec_dataCount; i++)
    {
        mod_hnr10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_hnr10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_hnr10_hdr_aec_data;
    }
    mod_hnr10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_total_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_total_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    total_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_hnr10_total_scale_ratio_dataType_total_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_hnr10_total_scale_ratio_dataType::total_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_hnr10_drc_gain_dataCount; i++)
    {
        mod_hnr10_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_hnr10_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_hnr10_drc_gain_data;
    }
    mod_hnr10_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_hnr10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_hnr10_total_scale_ratio_dataCount; i++)
    {
        mod_hnr10_total_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_hnr10_total_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_hnr10_total_scale_ratio_data;
    }
    mod_hnr10_total_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_hnr10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_hnr10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10Type::Release()
{
    ((chromatix_hnr10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_hnr10Type::GetModified()
{
    return ((chromatix_hnr10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_hnr10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_hnr10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_hnr10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_hnr10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_hnr10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_hnr10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_hnr10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_hnr10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_hnr10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_hnr10TypeClass::Release()
{
    ParameterModule::Release();
}

HNR_1_0_0_NAMESPACE_END
